@@ -15,7 +15,7 @@ import warnings
 from numba.core.errors import NumbaWarning
 warnings.filterwarnings("ignore", category=NumbaWarning)
 
-__version__ = "0.7.8"
+__version__ = "0.7.9"
 
 """
 Copyright 2018, Alexander J. Tarashansky, All rights reserved.
@@ -188,8 +188,8 @@ class SAM(object):
             "thresh_high":thresh_high,
             "filter_genes": filter_genes,
         }
-
-
+        
+        self.run_args = self.adata.uns.get('run_args',{})
         # load data
         try:
             D = self.adata_raw.X
@@ -294,6 +294,7 @@ class SAM(object):
         self.adata.var['variances'] = var
 
         self.adata.uns["preprocess_args"] = self.preprocess_args
+        self.adata.uns['run_args'] = self.run_args
 
     def get_avg_obsm(self, keym, keyl):
         clu = self.get_labels_un(keyl)
@@ -341,7 +342,7 @@ class SAM(object):
         transpose=True,
         save_sparse_file=None,
         sep=",",
-        calculate_avg=True,
+        calculate_avg=False,
         **kwargs
     ):
         """Loads the specified data file. The file can be a table of
@@ -428,10 +429,10 @@ class SAM(object):
 
                 if (
                     "X_knn_avg" not in self.adata.layers.keys()
-                    and "neighbors" in self.adata.uns.keys()
+                    and "connectivities" in self.adata.obsp.keys()
                     and calculate_avg
                 ):
-                    self.dispersion_ranking_NN()
+                    self.dispersion_ranking_NN(save_avgs=True)
             else:
                 self.adata_raw = self.adata
 
@@ -1418,8 +1419,7 @@ class SAM(object):
         from sklearn.cluster import KMeans
 
         if X is None:
-            D_sub = self.X_processed[0]
-            X = ut.weighted_PCA(D_sub, npcs=npcs, do_weight=False)[0]
+            X = self.adata.obsm['X_pca']
 
         km = KMeans(n_clusters=numc)
         cl = km.fit_predict(Normalizer().fit_transform(X))
@@ -1476,9 +1476,7 @@ class SAM(object):
         import hdbscan
 
         if X is None:
-            # X = self.adata.obsm['X_pca']
-            D = self.X_processed[0]
-            X = ut.weighted_PCA(D, npcs=npcs, do_weight=False)[0]
+            X = self.adata.obsm['X_pca']
             X = Normalizer().fit_transform(X)
             save = True
         else:
@@ -1721,3 +1719,4 @@ class SAM(object):
             from samalg.gui import SAMGUI
             self.SamGui = SAMGUI(self)
             return self.SamGui.SamPlot
+            
\ No newline at end of file
