@@ -14,7 +14,7 @@ import warnings
 from numba.core.errors import NumbaWarning
 warnings.filterwarnings("ignore", category=NumbaWarning)
 
-__version__ = "0.7.8"
+__version__ = "0.7.9"
 
 
 class SAMGUI(object):
@@ -85,6 +85,7 @@ class SAMGUI(object):
         self.pp_box = self.init_preprocess()
         self.rs_box = self.init_run_sam()
         self.cs_box = self.init_cs()
+        
         self.SAM_LOADED = True
         self.out = widgets.Output(
             layout={"border": "1px solid black", "height": "95%", "width": "100%"}
@@ -153,13 +154,8 @@ class SAMGUI(object):
         rm = list(invalidArgs(self.sams[0].preprocess_data,self.preprocess_args))
         for k in rm:
             del self.preprocess_args[k]            
-        self.preprocess_args['filter_genes']=False
-        self.preprocess_args['min_expression']=0
-        self.preprocess_args['thresh']=0
-        self.preprocess_args['thresh_low']=0
-        self.preprocess_args['thresh_high']=1
-        self.preprocess_args['sum_norm']=None
-        self.preprocess_args['norm']=None
+            
+        self.preprocess_args['thresh'] = self.preprocess_args.get('thresh_low',0.0)
         self.preprocess_args_init = self.preprocess_args.copy()
 
         try:
@@ -340,17 +336,17 @@ class SAMGUI(object):
     """ BEGIN PREPROCESS INIT"""
 
     def init_preprocess(self):
-        """
+
         pdata = widgets.Button(
-            description = 'Process data',
+            description = 'Preprocess',
             disabled = False,
-            tooltip = 'Process data',
+            tooltip = 'Preprocess data',
             icon = ''
         )
         pdata.on_click(self.preprocess_sam)
-        """
+
         fgenes = widgets.Checkbox(
-            value=bool(self.preprocess_args.get("filter_genes", False)),
+            value=bool(self.preprocess_args.get("filter_genes", True)),
             description="Filter genes",
         )
         fgenes.observe(self.pp_filtergenes, names="value")
@@ -361,10 +357,10 @@ class SAMGUI(object):
             icon="",
         )
         dfts.on_click(self.set_pp_defaults)
-
+        
         l1 = widgets.Label("Expr threshold:")
         expr_thr = widgets.FloatSlider(
-            value=float(self.preprocess_args.get("thresh", 0.0)),
+            value=float(self.preprocess_args.get("thresh", 0.01)),
             min=0,
             max=0.1,
             step=0.005,
@@ -379,7 +375,7 @@ class SAMGUI(object):
 
         l2 = widgets.Label("Min expr:")
         min_expr = widgets.FloatSlider(
-            value=float(self.preprocess_args.get("min_expression", 0)),
+            value=float(self.preprocess_args.get("min_expression", 1)),
             min=0,
             max=6.0,
             step=0.02,
@@ -399,7 +395,7 @@ class SAMGUI(object):
             init = "None"
         sumnorm = widgets.Dropdown(
             options=["cell_median", "gene_median", "None"],
-            value="None",
+            value=init,
             description="Library normalization:",
             disabled=False,
             style={"description_width": "initial"},
@@ -413,7 +409,7 @@ class SAMGUI(object):
             init = "None"
         norm = widgets.Dropdown(
             options=["log", "ftt", "None"],
-            value="None",
+            value=init,
             description="Data normalization:",
             disabled=False,
             style={"description_width": "initial"},
@@ -449,6 +445,7 @@ class SAMGUI(object):
         load_datav = widgets.Text(value="", layout={"width": "100%%"})
 
         self.ps_dict = {}
+        self.ps_dict["PDATA"] = pdata
         self.ps_dict["DFTS"] = dfts
         self.ps_dict["FGENES"] = fgenes
         self.ps_dict["NORM"] = norm
@@ -465,7 +462,7 @@ class SAMGUI(object):
         self.ps_dict["LOAD_DATAV"] = load_datav
 
         pp = widgets.VBox(
-            [  # pdata,
+            [   pdata,
                 widgets.HBox([dfts, fgenes]),
                 norm,
                 sumnorm,
@@ -621,7 +618,7 @@ class SAMGUI(object):
         self.sams[i].preprocess_data(**self.preprocess_args)
 
     """ END PREPROCESS INIT"""
-
+    
     """ BEGIN RUN INIT"""
 
     def init_run_sam(self):
@@ -688,6 +685,13 @@ class SAMGUI(object):
         )
         wpca.observe(self.weightpcs)
 
+
+        spca = widgets.Checkbox(
+            value=bool(self.run_args.get("sparse_pca", True)), description="Sparse PCA"
+        )
+        spca.observe(self.sparsepca)
+        
+
         dfts = widgets.Button(
             description="Set defaults",
             disabled=False,
@@ -842,6 +846,7 @@ class SAMGUI(object):
         proj.observe(self.proj_update, "value")
 
         self.rb_dict = {}
+        self.rb_dict['SPCA'] = spca
         self.rb_dict["RUNB"] = runb
         self.rb_dict["TITLE"] = title
         self.rb_dict["DFTS"] = dfts
@@ -867,7 +872,7 @@ class SAMGUI(object):
         rs = widgets.VBox(
             [
                 widgets.HBox([runb, title]),
-                widgets.HBox([dfts, wpca]),
+                widgets.HBox([dfts, wpca, spca]),
                 widgets.HBox([l3, knn]),
                 widgets.HBox([l4, nna]),
                 norm,
@@ -952,6 +957,11 @@ class SAMGUI(object):
         self.log('Setting weight_PCs to be {}'.format(not t))
         self.run_args["weight_PCs"] = not t
 
+    def sparsepca(self, event):
+        t = self.run_args.get("sparse_pca", True)
+        self.log('Setting sparse_pca to be {}'.format(not t))
+        self.run_args["sparse_pca"] = not t
+        
     def npcs_update(self, val):
         self.log('Setting npcs to be {}'.format(int(val['new'])))
         self.run_args["npcs"] = int(val["new"])
@@ -993,15 +1003,14 @@ class SAMGUI(object):
 
         sam = self.sams[i]
         if not np.all(selected) and selected.sum() > 0:
-            sam_subcluster = SAM(counts=sam.adata_raw[selected_cells, :].copy())
+            sam_subcluster = SAM(counts=sam.adata[selected_cells, :].copy())
+            sam_subcluster.adata_raw = sam.adata_raw[selected_cells].copy()
 
-            sam_subcluster.adata_raw.obs = sam.adata[selected_cells, :].obs.copy()
-            sam_subcluster.adata.obs = sam.adata[selected_cells, :].obs.copy()
+            sam_subcluster.adata_raw.obs = sam_subcluster.adata.obs.copy()
+            sam_subcluster.adata_raw.obsm = sam_subcluster.adata.obsm.copy()
 
-            sam_subcluster.adata_raw.obsm = sam.adata[selected_cells, :].obsm.copy()
-            sam_subcluster.adata.obsm = sam.adata[selected_cells, :].obsm.copy()
-
-            sam_subcluster.preprocess_data(**self.preprocess_args)
+            #sam_subcluster.preprocess_data(**self.preprocess_args)
+            
             self.out.clear_output()
             with self.out:
                 sam_subcluster.run(**self.run_args)
@@ -1967,3 +1976,4 @@ def invalidArgs(func, argdict):
     import inspect
     args = inspect.getfullargspec(func).args
     return set(argdict) - set(args)
+    
\ No newline at end of file
